@@ -1,5 +1,5 @@
 /*
- * Copyright  2003 Carl Worth
+ * Copyright © 2003 Carl Worth
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -33,10 +33,15 @@
 #include <string.h>
 #include <limits.h>
 
-
-
 #include "slim_internal.h"
 
+#ifndef __GNUC__
+#define __inline
+#endif
+
+#define MIN(a,b) ((a) < (b) ? (a) : (b))
+#define MAX(a,b) ((a) > (b) ? (a) : (b))
+
 /* C89 has implementation-defined behavior for % with negative operands.
    C99 has well-defined behavior which is that / with integers rounds toward zero
        and a%b is defined so that (a/b)*b + a%b == a.
@@ -49,13 +54,14 @@
 */
 #define MOD(a, b) ((b) == 1 ? 0 : (a) >= 0 ? (a) % (b) : (b) - (-(a) - 1) % (b) - 1)
 
-typedef struct _IcPoint {
+typedef struct _FbPoint {
 	int16_t    x,y ;
-} IcPoint;
+} FbPoint;
 
 typedef unsigned int	Mask;
 
 
+#define GXcopy		0x3
 #define GXor		0x7
 #define ClipByChildren  0
 #define PolyEdgeSharp   0
@@ -64,7 +70,27 @@ typedef unsigned int	Mask;
 #define CPLastBit       11
 
 
+/* Define any names that the server code will be expecting in
+ * terms of libpixman names. */
 
+typedef uint8_t			CARD8;
+typedef uint16_t		CARD16;
+typedef uint32_t		CARD32;
+typedef int16_t			INT16;
+
+typedef int			Bool;
+#define FALSE 0
+#define TRUE  1
+
+typedef pixman_bits_t		FbBits;
+typedef pixman_image_t*		PicturePtr;
+typedef pixman_box16_t		BoxRec;
+typedef pixman_box16_t*		BoxPtr;
+
+typedef pixman_point_fixed_t	xPointFixed;
+typedef pixman_line_fixed_t	xLineFixed;
+typedef pixman_trapezoid_t	xTrapezoid;
+typedef pixman_triangle_t	xTriangle;
 
 /* These few definitions avoid me needing to include servermd.h and misc.h from Xserver/include */
 #ifndef BITMAP_SCANLINE_PAD
@@ -100,14 +126,14 @@ typedef unsigned int	Mask;
    drop quite a bit of it. Once the real ic code starts to come
    together I can probably figure out what is not needed here. */
 
-#define IC_UNIT	    (1 << IC_SHIFT)
-#define IC_HALFUNIT (1 << (IC_SHIFT-1))
-#define IC_MASK	    (IC_UNIT - 1)
-#define IC_ALLONES  ((pixman_bits_t) -1)
+#define FB_UNIT	    (1 << FB_SHIFT)
+#define FB_HALFUNIT (1 << (FB_SHIFT-1))
+#define FB_MASK	    (FB_UNIT - 1)
+#define FB_ALLONES  ((pixman_bits_t) -1)
     
 /* whether to bother to include 24bpp support */
 #ifndef ICNO24BIT
-#define IC_24BIT
+#define FB_24BIT
 #endif
 
 /*
@@ -115,149 +141,149 @@ typedef unsigned int	Mask;
  * windows with 32bpp image format for application compatibility
  */
 
-#ifdef IC_24BIT
+#ifdef FB_24BIT
 #ifndef ICNO24_32
-#define IC_24_32BIT
+#define FB_24_32BIT
 #endif
 #endif
 
-#define IC_STIP_SHIFT	LOG2_BITMAP_PAD
-#define IC_STIP_UNIT	(1 << IC_STIP_SHIFT)
-#define IC_STIP_MASK	(IC_STIP_UNIT - 1)
-#define IC_STIP_ALLONES	((IcStip) -1)
+#define FB_STIP_SHIFT	LOG2_BITMAP_PAD
+#define FB_STIP_UNIT	(1 << FB_STIP_SHIFT)
+#define FB_STIP_MASK	(FB_STIP_UNIT - 1)
+#define FB_STIP_ALLONES	((FbStip) -1)
     
-#define IC_STIP_ODDSTRIDE(s)	(((s) & (IC_MASK >> IC_STIP_SHIFT)) != 0)
-#define IC_STIP_ODDPTR(p)	((((long) (p)) & (IC_MASK >> 3)) != 0)
+#define FB_STIP_ODDSTRIDE(s)	(((s) & (FB_MASK >> FB_STIP_SHIFT)) != 0)
+#define FB_STIP_ODDPTR(p)	((((long) (p)) & (FB_MASK >> 3)) != 0)
     
-#define IcStipStrideToBitsStride(s) (((s) >> (IC_SHIFT - IC_STIP_SHIFT)))
-#define IcBitsStrideToStipStride(s) (((s) << (IC_SHIFT - IC_STIP_SHIFT)))
+#define FbStipStrideToBitsStride(s) (((s) >> (FB_SHIFT - FB_STIP_SHIFT)))
+#define FbBitsStrideToStipStride(s) (((s) << (FB_SHIFT - FB_STIP_SHIFT)))
     
-#define IcFullMask(n)   ((n) == IC_UNIT ? IC_ALLONES : ((((pixman_bits_t) 1) << n) - 1))
+#define FbFullMask(n)   ((n) == FB_UNIT ? FB_ALLONES : ((((FbBits) 1) << n) - 1))
 
 
-typedef uint32_t	    IcStip;
-typedef int		    IcStride;
+typedef uint32_t	    FbStip;
+typedef int		    FbStride;
 
 
-#ifdef IC_DEBUG
-extern void IcValidateDrawable(DrawablePtr d);
-extern void IcInitializeDrawable(DrawablePtr d);
-extern void IcSetBits (IcStip *bits, int stride, IcStip data);
-#define IC_HEAD_BITS   (IcStip) (0xbaadf00d)
-#define IC_TAIL_BITS   (IcStip) (0xbaddf0ad)
+#ifdef FB_DEBUG
+extern void fbValidateDrawable(DrawablePtr d);
+extern void fbInitializeDrawable(DrawablePtr d);
+extern void fbSetBits (FbStip *bits, int stride, FbStip data);
+#define FB_HEAD_BITS   (FbStip) (0xbaadf00d)
+#define FB_TAIL_BITS   (FbStip) (0xbaddf0ad)
 #else
-#define IcValidateDrawable(d)
+#define fbValidateDrawable(d)
 #define fdInitializeDrawable(d)
 #endif
 
 #if BITMAP_BIT_ORDER == LSBFirst
-#define IcScrLeft(x,n)	((x) >> (n))
-#define IcScrRight(x,n)	((x) << (n))
-/* #define IcLeftBits(x,n)	((x) & ((((pixman_bits_t) 1) << (n)) - 1)) */
-#define IcLeftStipBits(x,n) ((x) & ((((IcStip) 1) << (n)) - 1))
-#define IcStipMoveLsb(x,s,n)	(IcStipRight (x,(s)-(n)))
-#define IcPatternOffsetBits	0
+#define FbScrLeft(x,n)	((x) >> (n))
+#define FbScrRight(x,n)	((x) << (n))
+/* #define FbLeftBits(x,n)	((x) & ((((FbBits) 1) << (n)) - 1)) */
+#define FbLeftStipBits(x,n) ((x) & ((((FbStip) 1) << (n)) - 1))
+#define FbStipMoveLsb(x,s,n)	(FbStipRight (x,(s)-(n)))
+#define FbPatternOffsetBits	0
 #else
-#define IcScrLeft(x,n)	((x) << (n))
-#define IcScrRight(x,n)	((x) >> (n))
-/* #define IcLeftBits(x,n)	((x) >> (IC_UNIT - (n))) */
-#define IcLeftStipBits(x,n) ((x) >> (IC_STIP_UNIT - (n)))
-#define IcStipMoveLsb(x,s,n)	(x)
-#define IcPatternOffsetBits	(sizeof (pixman_bits_t) - 1)
+#define FbScrLeft(x,n)	((x) << (n))
+#define FbScrRight(x,n)	((x) >> (n))
+/* #define FbLeftBits(x,n)	((x) >> (FB_UNIT - (n))) */
+#define FbLeftStipBits(x,n) ((x) >> (FB_STIP_UNIT - (n)))
+#define FbStipMoveLsb(x,s,n)	(x)
+#define FbPatternOffsetBits	(sizeof (FbBits) - 1)
 #endif
 
-#define IcStipLeft(x,n)	IcScrLeft(x,n)
-#define IcStipRight(x,n) IcScrRight(x,n)
+#define FbStipLeft(x,n)	FbScrLeft(x,n)
+#define FbStipRight(x,n) FbScrRight(x,n)
 
-#define IcRotLeft(x,n)	IcScrLeft(x,n) | (n ? IcScrRight(x,IC_UNIT-n) : 0)
-#define IcRotRight(x,n)	IcScrRight(x,n) | (n ? IcScrLeft(x,IC_UNIT-n) : 0)
+#define FbRotLeft(x,n)	FbScrLeft(x,n) | (n ? FbScrRight(x,FB_UNIT-n) : 0)
+#define FbRotRight(x,n)	FbScrRight(x,n) | (n ? FbScrLeft(x,FB_UNIT-n) : 0)
 
-#define IcRotStipLeft(x,n)  IcStipLeft(x,n) | (n ? IcStipRight(x,IC_STIP_UNIT-n) : 0)
-#define IcRotStipRight(x,n)  IcStipRight(x,n) | (n ? IcStipLeft(x,IC_STIP_UNIT-n) : 0)
+#define FbRotStipLeft(x,n)  FbStipLeft(x,n) | (n ? FbStipRight(x,FB_STIP_UNIT-n) : 0)
+#define FbRotStipRight(x,n)  FbStipRight(x,n) | (n ? FbStipLeft(x,FB_STIP_UNIT-n) : 0)
 
-#define IcLeftMask(x)	    ( ((x) & IC_MASK) ? \
-			     IcScrRight(IC_ALLONES,(x) & IC_MASK) : 0)
-#define IcRightMask(x)	    ( ((IC_UNIT - (x)) & IC_MASK) ? \
-			     IcScrLeft(IC_ALLONES,(IC_UNIT - (x)) & IC_MASK) : 0)
+#define FbLeftMask(x)	    ( ((x) & FB_MASK) ? \
+			     FbScrRight(FB_ALLONES,(x) & FB_MASK) : 0)
+#define FbRightMask(x)	    ( ((FB_UNIT - (x)) & FB_MASK) ? \
+			     FbScrLeft(FB_ALLONES,(FB_UNIT - (x)) & FB_MASK) : 0)
 
-#define IcLeftStipMask(x)   ( ((x) & IC_STIP_MASK) ? \
-			     IcStipRight(IC_STIP_ALLONES,(x) & IC_STIP_MASK) : 0)
-#define IcRightStipMask(x)  ( ((IC_STIP_UNIT - (x)) & IC_STIP_MASK) ? \
-			     IcScrLeft(IC_STIP_ALLONES,(IC_STIP_UNIT - (x)) & IC_STIP_MASK) : 0)
+#define FbLeftStipMask(x)   ( ((x) & FB_STIP_MASK) ? \
+			     FbStipRight(FB_STIP_ALLONES,(x) & FB_STIP_MASK) : 0)
+#define FbRightStipMask(x)  ( ((FB_STIP_UNIT - (x)) & FB_STIP_MASK) ? \
+			     FbScrLeft(FB_STIP_ALLONES,(FB_STIP_UNIT - (x)) & FB_STIP_MASK) : 0)
 
-#define IcBitsMask(x,w)	(IcScrRight(IC_ALLONES,(x) & IC_MASK) & \
-			 IcScrLeft(IC_ALLONES,(IC_UNIT - ((x) + (w))) & IC_MASK))
+#define FbBitsMask(x,w)	(FbScrRight(FB_ALLONES,(x) & FB_MASK) & \
+			 FbScrLeft(FB_ALLONES,(FB_UNIT - ((x) + (w))) & FB_MASK))
 
-#define IcStipMask(x,w)	(IcStipRight(IC_STIP_ALLONES,(x) & IC_STIP_MASK) & \
-			 IcStipLeft(IC_STIP_ALLONES,(IC_STIP_UNIT - ((x)+(w))) & IC_STIP_MASK))
+#define FbStipMask(x,w)	(FbStipRight(FB_STIP_ALLONES,(x) & FB_STIP_MASK) & \
+			 FbStipLeft(FB_STIP_ALLONES,(FB_STIP_UNIT - ((x)+(w))) & FB_STIP_MASK))
 
 
-#define IcMaskBits(x,w,l,n,r) { \
+#define FbMaskBits(x,w,l,n,r) { \
     n = (w); \
-    r = IcRightMask((x)+n); \
-    l = IcLeftMask(x); \
+    r = FbRightMask((x)+n); \
+    l = FbLeftMask(x); \
     if (l) { \
-	n -= IC_UNIT - ((x) & IC_MASK); \
+	n -= FB_UNIT - ((x) & FB_MASK); \
 	if (n < 0) { \
 	    n = 0; \
 	    l &= r; \
 	    r = 0; \
 	} \
     } \
-    n >>= IC_SHIFT; \
+    n >>= FB_SHIFT; \
 }
 
 #ifdef ICNOPIXADDR
-#define IcMaskBitsBytes(x,w,copy,l,lb,n,r,rb) IcMaskBits(x,w,l,n,r)
-#define IcDoLeftMaskByteRRop(dst,lb,l,and,xor) { \
-    *dst = IcDoMaskRRop(*dst,and,xor,l); \
+#define FbMaskBitsBytes(x,w,copy,l,lb,n,r,rb) FbMaskBits(x,w,l,n,r)
+#define FbDoLeftMaskByteRRop(dst,lb,l,and,xor) { \
+    *dst = FbDoMaskRRop(*dst,and,xor,l); \
 }
-#define IcDoRightMaskByteRRop(dst,rb,r,and,xor) { \
-    *dst = IcDoMaskRRop(*dst,and,xor,r); \
+#define FbDoRightMaskByteRRop(dst,rb,r,and,xor) { \
+    *dst = FbDoMaskRRop(*dst,and,xor,r); \
 }
 #else
 
-#define IcByteMaskInvalid   0x10
+#define FbByteMaskInvalid   0x10
 
-#define IcPatternOffset(o,t)  ((o) ^ (IcPatternOffsetBits & ~(sizeof (t) - 1)))
+#define FbPatternOffset(o,t)  ((o) ^ (FbPatternOffsetBits & ~(sizeof (t) - 1)))
 
-#define IcPtrOffset(p,o,t)		((t *) ((uint8_t *) (p) + (o)))
-#define IcSelectPatternPart(xor,o,t)	((xor) >> (IcPatternOffset (o,t) << 3))
-#define IcStorePart(dst,off,t,xor)	(*IcPtrOffset(dst,off,t) = \
-					 IcSelectPart(xor,off,t))
-#ifndef IcSelectPart
-#define IcSelectPart(x,o,t) IcSelectPatternPart(x,o,t)
+#define FbPtrOffset(p,o,t)		((t *) ((CARD8 *) (p) + (o)))
+#define FbSelectPatternPart(xor,o,t)	((xor) >> (FbPatternOffset (o,t) << 3))
+#define FbStorePart(dst,off,t,xor)	(*FbPtrOffset(dst,off,t) = \
+					 FbSelectPart(xor,off,t))
+#ifndef FbSelectPart
+#define FbSelectPart(x,o,t) FbSelectPatternPart(x,o,t)
 #endif
 
-#define IcMaskBitsBytes(x,w,copy,l,lb,n,r,rb) { \
+#define FbMaskBitsBytes(x,w,copy,l,lb,n,r,rb) { \
     n = (w); \
     lb = 0; \
     rb = 0; \
-    r = IcRightMask((x)+n); \
+    r = FbRightMask((x)+n); \
     if (r) { \
 	/* compute right byte length */ \
 	if ((copy) && (((x) + n) & 7) == 0) { \
-	    rb = (((x) + n) & IC_MASK) >> 3; \
+	    rb = (((x) + n) & FB_MASK) >> 3; \
 	} else { \
-	    rb = IcByteMaskInvalid; \
+	    rb = FbByteMaskInvalid; \
 	} \
     } \
-    l = IcLeftMask(x); \
+    l = FbLeftMask(x); \
     if (l) { \
 	/* compute left byte length */ \
 	if ((copy) && ((x) & 7) == 0) { \
-	    lb = ((x) & IC_MASK) >> 3; \
+	    lb = ((x) & FB_MASK) >> 3; \
 	} else { \
-	    lb = IcByteMaskInvalid; \
+	    lb = FbByteMaskInvalid; \
 	} \
 	/* subtract out the portion painted by leftMask */ \
-	n -= IC_UNIT - ((x) & IC_MASK); \
+	n -= FB_UNIT - ((x) & FB_MASK); \
 	if (n < 0) { \
-	    if (lb != IcByteMaskInvalid) { \
-		if (rb == IcByteMaskInvalid) { \
-		    lb = IcByteMaskInvalid; \
+	    if (lb != FbByteMaskInvalid) { \
+		if (rb == FbByteMaskInvalid) { \
+		    lb = FbByteMaskInvalid; \
 		} else if (rb) { \
-		    lb |= (rb - lb) << (IC_SHIFT - 3); \
+		    lb |= (rb - lb) << (FB_SHIFT - 3); \
 		    rb = 0; \
 		} \
 	    } \
@@ -266,182 +292,182 @@ extern void IcSetBits (IcStip *bits, int stride, IcStip data);
 	    r = 0; \
 	}\
     } \
-    n >>= IC_SHIFT; \
+    n >>= FB_SHIFT; \
 }
 
-#if IC_SHIFT == 6
-#define IcDoLeftMaskByteRRop6Cases(dst,xor) \
-    case (sizeof (pixman_bits_t) - 7) | (1 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
+#if FB_SHIFT == 6
+#define FbDoLeftMaskByteRRop6Cases(dst,xor) \
+    case (sizeof (FbBits) - 7) | (1 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 7,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 7) | (2 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint8_t,xor); \
+    case (sizeof (FbBits) - 7) | (2 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 7,CARD8,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 7) | (3 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
+    case (sizeof (FbBits) - 7) | (3 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 7,CARD8,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD16,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 7) | (4 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint8_t,xor); \
+    case (sizeof (FbBits) - 7) | (4 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 7,CARD8,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 7) | (5 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
+    case (sizeof (FbBits) - 7) | (5 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 7,CARD8,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD16,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 7) | (6 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint8_t,xor); \
+    case (sizeof (FbBits) - 7) | (6 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 7,CARD8,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 2,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 7): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint32_t,xor); \
+    case (sizeof (FbBits) - 7): \
+	FbStorePart(dst,sizeof (FbBits) - 7,CARD8,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD32,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 6) | (1 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint8_t,xor); \
+    case (sizeof (FbBits) - 6) | (1 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 6) | (2 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
+    case (sizeof (FbBits) - 6) | (2 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD16,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 6) | (3 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint8_t,xor); \
+    case (sizeof (FbBits) - 6) | (3 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 6) | (4 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
+    case (sizeof (FbBits) - 6) | (4 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD16,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 6) | (5 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint8_t,xor); \
+    case (sizeof (FbBits) - 6) | (5 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 2,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 6): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint32_t,xor); \
+    case (sizeof (FbBits) - 6): \
+	FbStorePart(dst,sizeof (FbBits) - 6,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD32,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 5) | (1 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 5,uint8_t,xor); \
+    case (sizeof (FbBits) - 5) | (1 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 5,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 5) | (2 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 5,uint8_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint8_t,xor); \
+    case (sizeof (FbBits) - 5) | (2 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 5,CARD8,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 5) | (3 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 5,uint8_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
+    case (sizeof (FbBits) - 5) | (3 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 5,CARD8,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD16,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 5) | (4 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 5,uint8_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint8_t,xor); \
+    case (sizeof (FbBits) - 5) | (4 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 5,CARD8,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 2,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 5): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 5,uint8_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint32_t,xor); \
+    case (sizeof (FbBits) - 5): \
+	FbStorePart(dst,sizeof (FbBits) - 5,CARD8,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD32,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 4) | (1 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint8_t,xor); \
+    case (sizeof (FbBits) - 4) | (1 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 4) | (2 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
+    case (sizeof (FbBits) - 4) | (2 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD16,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 4) | (3 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint8_t,xor); \
+    case (sizeof (FbBits) - 4) | (3 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD16,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 2,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 4): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint32_t,xor); \
+    case (sizeof (FbBits) - 4): \
+	FbStorePart(dst,sizeof (FbBits) - 4,CARD32,xor); \
 	break;
 
-#define IcDoRightMaskByteRRop6Cases(dst,xor) \
+#define FbDoRightMaskByteRRop6Cases(dst,xor) \
     case 4: \
-	IcStorePart(dst,0,uint32_t,xor); \
+	FbStorePart(dst,0,CARD32,xor); \
 	break; \
     case 5: \
-	IcStorePart(dst,0,uint32_t,xor); \
-	IcStorePart(dst,4,uint8_t,xor); \
+	FbStorePart(dst,0,CARD32,xor); \
+	FbStorePart(dst,4,CARD8,xor); \
 	break; \
     case 6: \
-	IcStorePart(dst,0,uint32_t,xor); \
-	IcStorePart(dst,4,uint16_t,xor); \
+	FbStorePart(dst,0,CARD32,xor); \
+	FbStorePart(dst,4,CARD16,xor); \
 	break; \
     case 7: \
-	IcStorePart(dst,0,uint32_t,xor); \
-	IcStorePart(dst,4,uint16_t,xor); \
-	IcStorePart(dst,6,uint8_t,xor); \
+	FbStorePart(dst,0,CARD32,xor); \
+	FbStorePart(dst,4,CARD16,xor); \
+	FbStorePart(dst,6,CARD8,xor); \
 	break;
 #else
-#define IcDoLeftMaskByteRRop6Cases(dst,xor)
-#define IcDoRightMaskByteRRop6Cases(dst,xor)
+#define FbDoLeftMaskByteRRop6Cases(dst,xor)
+#define FbDoRightMaskByteRRop6Cases(dst,xor)
 #endif
 
-#define IcDoLeftMaskByteRRop(dst,lb,l,and,xor) { \
+#define FbDoLeftMaskByteRRop(dst,lb,l,and,xor) { \
     switch (lb) { \
-    IcDoLeftMaskByteRRop6Cases(dst,xor) \
-    case (sizeof (pixman_bits_t) - 3) | (1 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 3,uint8_t,xor); \
+    FbDoLeftMaskByteRRop6Cases(dst,xor) \
+    case (sizeof (FbBits) - 3) | (1 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 3,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 3) | (2 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 3,uint8_t,xor); \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint8_t,xor); \
+    case (sizeof (FbBits) - 3) | (2 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 3,CARD8,xor); \
+	FbStorePart(dst,sizeof (FbBits) - 2,CARD8,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 2) | (1 << (IC_SHIFT - 3)): \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint8_t,xor); \
+    case (sizeof (FbBits) - 2) | (1 << (FB_SHIFT - 3)): \
+	FbStorePart(dst,sizeof (FbBits) - 2,CARD8,xor); \
 	break; \
-    case sizeof (pixman_bits_t) - 3: \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 3,uint8_t,xor); \
-    case sizeof (pixman_bits_t) - 2: \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint16_t,xor); \
+    case sizeof (FbBits) - 3: \
+	FbStorePart(dst,sizeof (FbBits) - 3,CARD8,xor); \
+    case sizeof (FbBits) - 2: \
+	FbStorePart(dst,sizeof (FbBits) - 2,CARD16,xor); \
 	break; \
-    case sizeof (pixman_bits_t) - 1: \
-	IcStorePart(dst,sizeof (pixman_bits_t) - 1,uint8_t,xor); \
+    case sizeof (FbBits) - 1: \
+	FbStorePart(dst,sizeof (FbBits) - 1,CARD8,xor); \
 	break; \
     default: \
-	*dst = IcDoMaskRRop(*dst, and, xor, l); \
+	*dst = FbDoMaskRRop(*dst, and, xor, l); \
 	break; \
     } \
 }
 
 
-#define IcDoRightMaskByteRRop(dst,rb,r,and,xor) { \
+#define FbDoRightMaskByteRRop(dst,rb,r,and,xor) { \
     switch (rb) { \
     case 1: \
-	IcStorePart(dst,0,uint8_t,xor); \
+	FbStorePart(dst,0,CARD8,xor); \
 	break; \
     case 2: \
-	IcStorePart(dst,0,uint16_t,xor); \
+	FbStorePart(dst,0,CARD16,xor); \
 	break; \
     case 3: \
-	IcStorePart(dst,0,uint16_t,xor); \
-	IcStorePart(dst,2,uint8_t,xor); \
+	FbStorePart(dst,0,CARD16,xor); \
+	FbStorePart(dst,2,CARD8,xor); \
 	break; \
-    IcDoRightMaskByteRRop6Cases(dst,xor) \
+    FbDoRightMaskByteRRop6Cases(dst,xor) \
     default: \
-	*dst = IcDoMaskRRop (*dst, and, xor, r); \
+	*dst = FbDoMaskRRop (*dst, and, xor, r); \
     } \
 }
 #endif
 
-#define IcMaskStip(x,w,l,n,r) { \
+#define FbMaskStip(x,w,l,n,r) { \
     n = (w); \
-    r = IcRightStipMask((x)+n); \
-    l = IcLeftStipMask(x); \
+    r = FbRightStipMask((x)+n); \
+    l = FbLeftStipMask(x); \
     if (l) { \
-	n -= IC_STIP_UNIT - ((x) & IC_STIP_MASK); \
+	n -= FB_STIP_UNIT - ((x) & FB_STIP_MASK); \
 	if (n < 0) { \
 	    n = 0; \
 	    l &= r; \
 	    r = 0; \
 	} \
     } \
-    n >>= IC_STIP_SHIFT; \
+    n >>= FB_STIP_SHIFT; \
 }
 
 /*
@@ -451,77 +477,77 @@ extern void IcSetBits (IcStip *bits, int stride, IcStip data);
  * sequence of partial word writes
  *
  * 'n' is the bytemask of which bytes to store, 'a' is the address
- * of the pixman_bits_t base unit, 'o' is the offset within that unit
+ * of the FbBits base unit, 'o' is the offset within that unit
  *
  * The term "lane" comes from the hardware term "byte-lane" which
  */
 
-#define IcLaneCase1(n,a,o)  ((n) == 0x01 ? \
-			     (*(uint8_t *) ((a)+IcPatternOffset(o,uint8_t)) = \
+#define FbLaneCase1(n,a,o)  ((n) == 0x01 ? \
+			     (*(CARD8 *) ((a)+FbPatternOffset(o,CARD8)) = \
 			      fgxor) : 0)
-#define IcLaneCase2(n,a,o)  ((n) == 0x03 ? \
-			     (*(uint16_t *) ((a)+IcPatternOffset(o,uint16_t)) = \
+#define FbLaneCase2(n,a,o)  ((n) == 0x03 ? \
+			     (*(CARD16 *) ((a)+FbPatternOffset(o,CARD16)) = \
 			      fgxor) : \
-			     ((void)IcLaneCase1((n)&1,a,o), \
-				    IcLaneCase1((n)>>1,a,(o)+1)))
-#define IcLaneCase4(n,a,o)  ((n) == 0x0f ? \
-			     (*(uint32_t *) ((a)+IcPatternOffset(o,uint32_t)) = \
+			     ((void)FbLaneCase1((n)&1,a,o), \
+				    FbLaneCase1((n)>>1,a,(o)+1)))
+#define FbLaneCase4(n,a,o)  ((n) == 0x0f ? \
+			     (*(CARD32 *) ((a)+FbPatternOffset(o,CARD32)) = \
 			      fgxor) : \
-			     ((void)IcLaneCase2((n)&3,a,o), \
-				    IcLaneCase2((n)>>2,a,(o)+2)))
-#define IcLaneCase8(n,a,o)  ((n) == 0x0ff ? (*(pixman_bits_t *) ((a)+(o)) = fgxor) : \
-			     ((void)IcLaneCase4((n)&15,a,o), \
-				    IcLaneCase4((n)>>4,a,(o)+4)))
+			     ((void)FbLaneCase2((n)&3,a,o), \
+				    FbLaneCase2((n)>>2,a,(o)+2)))
+#define FbLaneCase8(n,a,o)  ((n) == 0x0ff ? (*(FbBits *) ((a)+(o)) = fgxor) : \
+			     ((void)FbLaneCase4((n)&15,a,o), \
+				    FbLaneCase4((n)>>4,a,(o)+4)))
 
-#if IC_SHIFT == 6
-#define IcLaneCase(n,a)   IcLaneCase8(n,(uint8_t *) (a),0)
+#if FB_SHIFT == 6
+#define FbLaneCase(n,a)   FbLaneCase8(n,(CARD8 *) (a),0)
 #endif
 
-#if IC_SHIFT == 5
-#define IcLaneCase(n,a)   IcLaneCase4(n,(uint8_t *) (a),0)
+#if FB_SHIFT == 5
+#define FbLaneCase(n,a)   FbLaneCase4(n,(CARD8 *) (a),0)
 #endif
 
 /* Rotate a filled pixel value to the specified alignement */
-#define IcRot24(p,b)	    (IcScrRight(p,b) | IcScrLeft(p,24-(b)))
-#define IcRot24Stip(p,b)    (IcStipRight(p,b) | IcStipLeft(p,24-(b)))
+#define FbRot24(p,b)	    (FbScrRight(p,b) | FbScrLeft(p,24-(b)))
+#define FbRot24Stip(p,b)    (FbStipRight(p,b) | FbStipLeft(p,24-(b)))
 
-/* step a filled pixel value to the next/previous IC_UNIT alignment */
-#define IcNext24Pix(p)	(IcRot24(p,(24-IC_UNIT%24)))
-#define IcPrev24Pix(p)	(IcRot24(p,IC_UNIT%24))
-#define IcNext24Stip(p)	(IcRot24(p,(24-IC_STIP_UNIT%24)))
-#define IcPrev24Stip(p)	(IcRot24(p,IC_STIP_UNIT%24))
+/* step a filled pixel value to the next/previous FB_UNIT alignment */
+#define FbNext24Pix(p)	(FbRot24(p,(24-FB_UNIT%24)))
+#define FbPrev24Pix(p)	(FbRot24(p,FB_UNIT%24))
+#define FbNext24Stip(p)	(FbRot24(p,(24-FB_STIP_UNIT%24)))
+#define FbPrev24Stip(p)	(FbRot24(p,FB_STIP_UNIT%24))
 
 /* step a rotation value to the next/previous rotation value */
-#if IC_UNIT == 64
-#define IcNext24Rot(r)        ((r) == 16 ? 0 : (r) + 8)
-#define IcPrev24Rot(r)        ((r) == 0 ? 16 : (r) - 8)
+#if FB_UNIT == 64
+#define FbNext24Rot(r)        ((r) == 16 ? 0 : (r) + 8)
+#define FbPrev24Rot(r)        ((r) == 0 ? 16 : (r) - 8)
 
 #if IMAGE_BYTE_ORDER == MSBFirst
-#define IcFirst24Rot(x)		(((x) + 8) % 24)
+#define FbFirst24Rot(x)		(((x) + 8) % 24)
 #else
-#define IcFirst24Rot(x)		((x) % 24)
+#define FbFirst24Rot(x)		((x) % 24)
 #endif
 
 #endif
 
-#if IC_UNIT == 32
-#define IcNext24Rot(r)        ((r) == 0 ? 16 : (r) - 8)
-#define IcPrev24Rot(r)        ((r) == 16 ? 0 : (r) + 8)
+#if FB_UNIT == 32
+#define FbNext24Rot(r)        ((r) == 0 ? 16 : (r) - 8)
+#define FbPrev24Rot(r)        ((r) == 16 ? 0 : (r) + 8)
 
 #if IMAGE_BYTE_ORDER == MSBFirst
-#define IcFirst24Rot(x)		(((x) + 16) % 24)
+#define FbFirst24Rot(x)		(((x) + 16) % 24)
 #else
-#define IcFirst24Rot(x)		((x) % 24)
+#define FbFirst24Rot(x)		((x) % 24)
 #endif
 #endif
 
-#define IcNext24RotStip(r)        ((r) == 0 ? 16 : (r) - 8)
-#define IcPrev24RotStip(r)        ((r) == 16 ? 0 : (r) + 8)
+#define FbNext24RotStip(r)        ((r) == 0 ? 16 : (r) - 8)
+#define FbPrev24RotStip(r)        ((r) == 16 ? 0 : (r) + 8)
 
 /* Whether 24-bit specific code is needed for this filled pixel value */
-#define IcCheck24Pix(p)	((p) == IcNext24Pix(p))
+#define FbCheck24Pix(p)	((p) == FbNext24Pix(p))
 
-#define IcGetPixels(icpixels, pointer, _stride_, _bpp_, xoff, yoff) { \
+#define FbGetPixels(icpixels, pointer, _stride_, _bpp_, xoff, yoff) { \
     (pointer) = icpixels->data; \
     (_stride_) = icpixels->stride / sizeof(pixman_bits_t); \
     (_bpp_) = icpixels->bpp; \
@@ -529,124 +555,124 @@ extern void IcSetBits (IcStip *bits, int stride, IcStip data);
     (yoff) = icpixels->y; /* XXX: fb.h had this ifdef'd to constant 0. Why? */ \
 }
 
-#define IcGetStipPixels(icpixels, pointer, _stride_, _bpp_, xoff, yoff) { \
-    (pointer) = (IcStip *) icpixels->data; \
-    (_stride_) = icpixels->stride; \
+#define FbGetStipPixels(icpixels, pointer, _stride_, _bpp_, xoff, yoff) { \
+    (pointer) = (FbStip *) icpixels->data; \
+    (_stride_) = icpixels->stride / sizeof(FbStip); \
     (_bpp_) = icpixels->bpp; \
     (xoff) = icpixels->x; \
     (yoff) = icpixels->y; \
 }
 
-#ifdef IC_OLD_SCREEN
+#ifdef FB_OLD_SCREEN
 #define BitsPerPixel(d) (\
     ((1 << PixmapWidthPaddingInfo[d].padBytesLog2) * 8 / \
     (PixmapWidthPaddingInfo[d].padRoundUp+1)))
 #endif
 
-#define IcPowerOfTwo(w)	    (((w) & ((w) - 1)) == 0)
+#define FbPowerOfTwo(w)	    (((w) & ((w) - 1)) == 0)
 /*
- * Accelerated tiles are power of 2 width <= IC_UNIT
+ * Accelerated tiles are power of 2 width <= FB_UNIT
  */
-#define IcEvenTile(w)	    ((w) <= IC_UNIT && IcPowerOfTwo(w))
+#define FbEvenTile(w)	    ((w) <= FB_UNIT && FbPowerOfTwo(w))
 /*
- * Accelerated stipples are power of 2 width and <= IC_UNIT/dstBpp
+ * Accelerated stipples are power of 2 width and <= FB_UNIT/dstBpp
  * with dstBpp a power of 2 as well
  */
-#define IcEvenStip(w,bpp)   ((w) * (bpp) <= IC_UNIT && IcPowerOfTwo(w) && IcPowerOfTwo(bpp))
+#define FbEvenStip(w,bpp)   ((w) * (bpp) <= FB_UNIT && FbPowerOfTwo(w) && FbPowerOfTwo(bpp))
 
 /*
  * icblt.c
  */
 pixman_private void
-IcBlt (pixman_bits_t   *src, 
-       IcStride	srcStride,
+fbBlt (pixman_bits_t   *src, 
+       FbStride	srcStride,
        int	srcX,
        
-       pixman_bits_t   *dst,
-       IcStride dstStride,
+       FbBits   *dst,
+       FbStride dstStride,
        int	dstX,
        
        int	width, 
        int	height,
        
        int	alu,
-       pixman_bits_t	pm,
+       FbBits	pm,
        int	bpp,
        
-       int	reverse,
-       int	upsidedown);
+       Bool	reverse,
+       Bool	upsidedown);
 
 pixman_private void
-IcBlt24 (pixman_bits_t	    *srcLine,
-	 IcStride   srcStride,
+fbBlt24 (pixman_bits_t	    *srcLine,
+	 FbStride   srcStride,
 	 int	    srcX,
 
-	 pixman_bits_t	    *dstLine,
-	 IcStride   dstStride,
+	 FbBits	    *dstLine,
+	 FbStride   dstStride,
 	 int	    dstX,
 
 	 int	    width, 
 	 int	    height,
 
 	 int	    alu,
-	 pixman_bits_t	    pm,
+	 FbBits	    pm,
 
-	 int	    reverse,
-	 int	    upsidedown);
+	 Bool	    reverse,
+	 Bool	    upsidedown);
     
 pixman_private void
-IcBltStip (IcStip   *src,
-	   IcStride srcStride,	    /* in IcStip units, not pixman_bits_t units */
+fbBltStip (FbStip   *src,
+	   FbStride srcStride,	    /* in FbStip units, not FbBits units */
 	   int	    srcX,
 	   
-	   IcStip   *dst,
-	   IcStride dstStride,	    /* in IcStip units, not pixman_bits_t units */
+	   FbStip   *dst,
+	   FbStride dstStride,	    /* in FbStip units, not FbBits units */
 	   int	    dstX,
 
 	   int	    width, 
 	   int	    height,
 
 	   int	    alu,
-	   pixman_bits_t   pm,
+	   FbBits   pm,
 	   int	    bpp);
     
 /*
  * icbltone.c
  */
 pixman_private void
-IcBltOne (IcStip   *src,
-	  IcStride srcStride,
+fbBltOne (FbStip   *src,
+	  FbStride srcStride,
 	  int	   srcX,
-	  pixman_bits_t   *dst,
-	  IcStride dstStride,
+	  FbBits   *dst,
+	  FbStride dstStride,
 	  int	   dstX,
 	  int	   dstBpp,
 
 	  int	   width,
 	  int	   height,
 
-	  pixman_bits_t   fgand,
-	  pixman_bits_t   icxor,
-	  pixman_bits_t   bgand,
-	  pixman_bits_t   bgxor);
+	  FbBits   fgand,
+	  FbBits   fbxor,
+	  FbBits   bgand,
+	  FbBits   bgxor);
  
-#ifdef IC_24BIT
+#ifdef FB_24BIT
 pixman_private void
-IcBltOne24 (IcStip    *src,
-	  IcStride  srcStride,	    /* IcStip units per scanline */
+fbBltOne24 (FbStip    *src,
+	  FbStride  srcStride,	    /* FbStip units per scanline */
 	  int	    srcX,	    /* bit position of source */
-	  pixman_bits_t    *dst,
-	  IcStride  dstStride,	    /* pixman_bits_t units per scanline */
+	  FbBits    *dst,
+	  FbStride  dstStride,	    /* FbBits units per scanline */
 	  int	    dstX,	    /* bit position of dest */
 	  int	    dstBpp,	    /* bits per destination unit */
 
 	  int	    width,	    /* width in bits of destination */
 	  int	    height,	    /* height in scanlines */
 
-	  pixman_bits_t    fgand,	    /* rrop values */
-	  pixman_bits_t    fgxor,
-	  pixman_bits_t    bgand,
-	  pixman_bits_t    bgxor);
+	  FbBits    fgand,	    /* rrop values */
+	  FbBits    fgxor,
+	  FbBits    bgand,
+	  FbBits    bgxor);
 #endif
 
 /*
@@ -654,73 +680,73 @@ IcBltOne24 (IcStip    *src,
  */
 
 pixman_private void
-IcTransparentSpan (pixman_bits_t   *dst,
+fbTransparentSpan (pixman_bits_t   *dst,
 		   pixman_bits_t   stip,
 		   pixman_bits_t   fgxor,
 		   int	    n);
 
 pixman_private void
-IcEvenStipple (pixman_bits_t   *dst,
-	       IcStride dstStride,
+fbEvenStipple (pixman_bits_t   *dst,
+	       FbStride dstStride,
 	       int	dstX,
 	       int	dstBpp,
 
 	       int	width,
 	       int	height,
 
-	       IcStip   *stip,
-	       IcStride	stipStride,
+	       FbStip   *stip,
+	       FbStride	stipStride,
 	       int	stipHeight,
 
-	       pixman_bits_t   fgand,
-	       pixman_bits_t   fgxor,
-	       pixman_bits_t   bgand,
-	       pixman_bits_t   bgxor,
+	       FbBits   fgand,
+	       FbBits   fgxor,
+	       FbBits   bgand,
+	       FbBits   bgxor,
 
 	       int	xRot,
 	       int	yRot);
 
 pixman_private void
-IcOddStipple (pixman_bits_t	*dst,
-	      IcStride	dstStride,
+fbOddStipple (pixman_bits_t	*dst,
+	      FbStride	dstStride,
 	      int	dstX,
 	      int	dstBpp,
 
 	      int	width,
 	      int	height,
 
-	      IcStip	*stip,
-	      IcStride	stipStride,
+	      FbStip	*stip,
+	      FbStride	stipStride,
 	      int	stipWidth,
 	      int	stipHeight,
 
-	      pixman_bits_t	fgand,
-	      pixman_bits_t	fgxor,
-	      pixman_bits_t	bgand,
-	      pixman_bits_t	bgxor,
+	      FbBits	fgand,
+	      FbBits	fgxor,
+	      FbBits	bgand,
+	      FbBits	bgxor,
 
 	      int	xRot,
 	      int	yRot);
 
 pixman_private void
-IcStipple (pixman_bits_t   *dst,
-	   IcStride dstStride,
+fbStipple (pixman_bits_t   *dst,
+	   FbStride dstStride,
 	   int	    dstX,
 	   int	    dstBpp,
 
 	   int	    width,
 	   int	    height,
 
-	   IcStip   *stip,
-	   IcStride stipStride,
+	   FbStip   *stip,
+	   FbStride stipStride,
 	   int	    stipWidth,
 	   int	    stipHeight,
-	   int	    even,
+	   Bool	    even,
 
-	   pixman_bits_t   fgand,
-	   pixman_bits_t   fgxor,
-	   pixman_bits_t   bgand,
-	   pixman_bits_t   bgxor,
+	   FbBits   fgand,
+	   FbBits   fgxor,
+	   FbBits   bgand,
+	   FbBits   bgxor,
 
 	   int	    xRot,
 	   int	    yRot);
@@ -735,7 +761,7 @@ struct pixman_format {
     int		alpha, alphaMask;
 };
 
-typedef struct _IcPixels {
+typedef struct _FbPixels {
     pixman_bits_t		*data;
     unsigned int	width;
     unsigned int	height;
@@ -745,14 +771,14 @@ typedef struct _IcPixels {
     int			x;
     int			y;
     unsigned int	refcnt;
-} IcPixels;
+} FbPixels;
 
 /* XXX: This is to avoid including colormap.h from the server includes */
 typedef uint32_t Pixel;
 
 /* icutil.c */
 pixman_private pixman_bits_t
-IcReplicatePixel (Pixel p, int bpp);
+fbReplicatePixel (Pixel p, int bpp);
 
 /* fbtrap.c */
 
@@ -782,14 +808,14 @@ fbRasterizeTrapezoid (pixman_image_t		*pMask,
    good as the static function below.  */
 #if __GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4)
 # if __INT_MIN__ == 0x7fffffff
-#  define _IcOnes(mask)		__builtin_popcount(mask)
+#  define _FbOnes(mask)		__builtin_popcount(mask)
 # else
-#  define _IcOnes(mask)		__builtin_popcountl((mask) & 0xffffffff)
+#  define _FbOnes(mask)		__builtin_popcountl((mask) & 0xffffffff)
 # endif
 #else
 # define ICINT_NEED_IC_ONES
 int
-_IcOnes(unsigned long mask);
+_FbOnes(unsigned long mask);
 #endif
 
 /* icformat.c */
@@ -800,19 +826,19 @@ pixman_format_init (pixman_format_t *format, int format_code);
 /* icimage.c */
 
 pixman_private pixman_image_t *
-pixman_image_createForPixels (IcPixels	*pixels,
+pixman_image_createForPixels (FbPixels	*pixels,
 			pixman_format_t	*format);
 
 /* icpixels.c */
 
-pixman_private IcPixels *
-IcPixelsCreate (int width, int height, int depth);
+pixman_private FbPixels *
+FbPixelsCreate (int width, int height, int depth);
 
-pixman_private IcPixels *
-IcPixelsCreateForData (pixman_bits_t *data, int width, int height, int depth, int bpp, int stride);
+pixman_private FbPixels *
+FbPixelsCreateForData (pixman_bits_t *data, int width, int height, int depth, int bpp, int stride);
 
 pixman_private void
-IcPixelsDestroy (IcPixels *pixels);
+FbPixelsDestroy (FbPixels *pixels);
 
 /* ictransform.c */
 
