@@ -54,12 +54,12 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ******************************************************************/
-/* $Id: pixman.h,v 1.15 2004/09/12 13:06:50 davidr Exp $ */
+/* $Id: pixman.h,v 1.21 2005/06/25 01:21:16 jrmuizel Exp $ */
 
 /* libic.h */
 
 /*
- * Copyright  1998 Keith Packard
+ * Copyright © 1998 Keith Packard
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -84,7 +84,7 @@ SOFTWARE.
 #if defined (__SVR4) && defined (__sun)
 # include <sys/int_types.h>
 #else
-# if defined (__OpenBSD__)
+# if defined (__OpenBSD__) || defined (_AIX)
 #  include <inttypes.h>
 # else 
 #  include <stdint.h>
@@ -261,18 +261,19 @@ pixman_image_create (pixman_format_t	*format,
  * by this software; it must be log2(sizeof (pixman_bits_t) * 8)
  */
 
+/* We use a 32-bit size on all platforms, (even those with native 64
+ * bit types). This is consistent with the code currently in the X
+ * server, so it goes through much more well-tested code paths, (we
+ * saw rendering bugs when we tried IC_SHIFT==6 and uint64_t for
+ * pixman_bits_t on 64-bit platofrms). In addition, Keith says that
+ * his testing indicates that using 32-bits everywhere is a
+ * performance win in any case, (presumably due to 32-bit datapaths
+ * between the processor and the video card).
+*/
 #ifndef IC_SHIFT
-#  if defined(__alpha__) || defined(__alpha) || \
-      defined(ia64) || defined(__ia64__) || \
-      defined(__sparc64__) || \
-      defined(__s390x__) || \
-      defined(x86_64) || defined (__x86_64__)
-#define IC_SHIFT 6
-typedef uint64_t pixman_bits_t;
-#  else
 #define IC_SHIFT 5
+#define FB_SHIFT IC_SHIFT
 typedef uint32_t pixman_bits_t;
-#  endif
 #endif
 
 pixman_image_t *
@@ -288,7 +289,7 @@ int
 pixman_image_set_clip_region (pixman_image_t	*image,
 			      pixman_region16_t	*region);
 
-typedef int pixman_fixed16_16_t;
+typedef int32_t pixman_fixed16_16_t;
 
 typedef struct pixman_point_fixed {
     pixman_fixed16_16_t  x, y;
@@ -414,6 +415,13 @@ pixman_composite_trapezoids (pixman_operator_t		op,
 			     const pixman_trapezoid_t *traps,
 			     int			ntrap);
 
+void
+pixman_add_trapezoids (pixman_image_t		*dst,
+		       int			x_off,
+		       int			y_off,
+		       const pixman_trapezoid_t	*traps,
+		       int			ntraps);
+
 /* ictri.c */
 
 void
